@@ -4,7 +4,7 @@ import wsgi
 
 class Cfg(object):
     DEBUG = False
-    BASIC_AUTH_SSL_ONLY = True  # basic-авторизация только по https
+    BASIC_AUTH_SSL_ONLY = False  # basic-авторизация только по https
     BASIC_AUTH_DB = {}
     INSTALLED_APPS = []
     CONTEXT_PROCESSORS = []
@@ -14,15 +14,12 @@ class Cfg(object):
     CHARSET = 'utf-8'
     POST_MAX_SIZE = 1024 * 1024 * 1  # максимальный размер пост-данных, None - не ограничивать
     POST_MAX_MEMFILE = 1024 * 100  # максимальный размер POST-данных, загружаемый в память. Если больше, создаётся временный файл.
-    ERROR_PAGES = {
-        404: lambda rq: wsgi.Response(wsgi.HTML_404, code=404, content_type='text/html'),
-        500: lambda rq: wsgi.Response(wsgi.HTML_500, code=500, content_type='text/html'),
-    }
+    ERROR_PAGES = {}
     TEMPLATE_CACHE_SIZE = 250
     TEMPLATE_AUTO_RELOAD = False
     TEMPLATE_LOADER = 'pysi.template.file_loader'
     FLASH_COOKIE_NAME = u'pysi.flash'
-    ROUTING = 'pysi.auto_routing'  # функция или очередь функция роутинга
+    ROUTING = 'pysi.auto_routing'  # функция или очередь функций роутинга
 
     def set_defaults(self, **kwargs):
         '''
